@@ -5,7 +5,7 @@ import attr
 from kslurm.args import TailArg
 from kslurm.args.arg_types import SubCommand
 from kslurm.args.command import command
-from kslurm.cli import kbatch, kjupyter, krun
+from kslurm.cli import kbatch, kjupyter, kpy, krun
 from kslurm.cli.config import config
 from kslurm.installer import install
 
@@ -21,8 +21,9 @@ class KslurmModel:
             "kbatch": kbatch,
             "krun": krun,
             "kjupyter": kjupyter,
+            "kpy": kpy,
             "config": config,
-            "install": lambda x: None,  # type: ignore
+            "update": lambda x: None,  # type: ignore
         },
     )
 
@@ -34,7 +35,7 @@ def main(args: KslurmModel) -> None:
     command = args.command.value
     tail = args.tail
     name = f"kslurm {args.command.raw_value}"
-    if args.command.raw_value == "install":
+    if args.command.raw_value == "update":
         install(tail.values, NAME, HOME_DIR, ENTRYPOINTS)
     command([name, *tail.values])
 
